Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(337)

Unified Diff: content/public/browser/download_item.h

Issue 2439533002: Download Feedback Service should upload all eligible downloads (Closed)
Patch Set: make windows bots happy Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/public/browser/download_item.h
diff --git a/content/public/browser/download_item.h b/content/public/browser/download_item.h
index cce08280a5858cbe14887b906028cb90b73f3668..32963bfd476415a5b22a75857900d68b462c7527 100644
--- a/content/public/browser/download_item.h
+++ b/content/public/browser/download_item.h
@@ -115,12 +115,15 @@ class CONTENT_EXPORT DownloadItem : public base::SupportsUserData {
// Called when the user has validated the download of a dangerous file.
virtual void ValidateDangerousDownload() = 0;
// Called to acquire a dangerous download and remove the DownloadItem from
// views and history. |callback| will be invoked on the UI thread with the
// path to the downloaded file. The caller is responsible for cleanup.
// Note: It is important for |callback| to be valid since the downloaded file
// will not be cleaned up if the callback fails.
- virtual void StealDangerousDownload(const AcquireFileCallback& callback) = 0;
+ virtual void StealDangerousDownload(bool delete_file_afterward,
+ const AcquireFileCallback& callback) = 0;
// Pause a download. Will have no effect if the download is already
// paused.
« no previous file with comments | « content/browser/download/download_manager_impl_unittest.cc ('k') | content/public/test/mock_download_item.h » ('j') | no next file with comments »
@@ -115,12 +115,15 @@ class CONTENT_EXPORT DownloadItem : public base::SupportsUserData {
// Called when the user has validated the download of a dangerous file.
virtual void ValidateDangerousDownload() = 0;
- // Called to acquire a dangerous download and remove the DownloadItem from
- // views and history. |callback| will be invoked on the UI thread with the
- // path to the downloaded file. The caller is responsible for cleanup.
+ // Called to acquire a dangerous download. If |delete_file_afterward| is true,
+ // invokes |callback| on the UI thread with the path to the downloaded file,
+ // and removes the DownloadItem from views and history if appropriate.
+ // Otherwise, makes a temp copy of the download file, and invokes |callback|
+ // with the path to the temp copy. The caller is responsible for cleanup.
// Note: It is important for |callback| to be valid since the downloaded file
// will not be cleaned up if the callback fails.

Powered by Google App Engine
This is Rietveld 408576698